==> igniteui-webcomponents-layouts-4.8.1.tgz: package/esm2015/lib/igc-tool-action-checkbox-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionCheckboxComponent = /*@__PURE__*/ (() => {
    class IgcToolActionCheckboxComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionCheckbox();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent == null) {
                let names = getAllPropertyNames(IgcToolActionCheckboxComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = names;
            }
            return IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent;
        }
        static register() {
            if (!IgcToolActionCheckboxComponent._isElementRegistered) {
                IgcToolActionCheckboxComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionCheckboxComponent.htmlTagName, IgcToolActionCheckboxComponent);
            }
        }
        /**
         * Gets or sets if the tool action is checked.
        */
        get isChecked() {
            return this.i.f8;
        }
        set isChecked(v) {
            this.i.f8 = ensureBool(v);
            this._a("isChecked", this.i.f8);
        }
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get uncheckedBackgroundColor() {
            return brushToString(this.i.gy);
        }
        set uncheckedBackgroundColor(v) {
            this.i.gy = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.gy));
        }
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get actualUncheckedBackgroundColor() {
            return brushToString(this.i.gu);
        }
        set actualUncheckedBackgroundColor(v) {
            this.i.gu = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.gu));
        }
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get checkedBackgroundColor() {
            return brushToString(this.i.gw);
        }
        set checkedBackgroundColor(v) {
            this.i.gw = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.gw));
        }
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get actualCheckedBackgroundColor() {
            return brushToString(this.i.gs);
        }
        set actualCheckedBackgroundColor(v) {
            this.i.gs = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.gs));
        }
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get uncheckedBorderColor() {
            return brushToString(this.i.gz);
        }
        set uncheckedBorderColor(v) {
            this.i.gz = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.gz));
        }
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get actualUncheckedBorderColor() {
            return brushToString(this.i.gv);
        }
        set actualUncheckedBorderColor(v) {
            this.i.gv = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.gv));
        }
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get checkedBorderColor() {
            return brushToString(this.i.gx);
        }
        set checkedBorderColor(v) {
            this.i.gx = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.gx));
        }
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get actualCheckedBorderColor() {
            return brushToString(this.i.gt);
        }
        set actualCheckedBorderColor(v) {
            this.i.gt = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.gt));
        }
        fromInfo(info) {
            this.i.ej(info);
        }
    }
    IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = null;
    IgcToolActionCheckboxComponent.htmlTagName = "igc-tool-action-checkbox";
    IgcToolActionCheckboxComponent._isElementRegistered = false;
    return IgcToolActionCheckboxComponent;
})();

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm2015/lib/igc-tool-action-checkbox-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionCheckboxComponent = /*@__PURE__*/ (() => {
    class IgcToolActionCheckboxComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionCheckbox();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent == null) {
                let names = getAllPropertyNames(IgcToolActionCheckboxComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = names;
            }
            return IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent;
        }
        static register() {
            if (!IgcToolActionCheckboxComponent._isElementRegistered) {
                IgcToolActionCheckboxComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionCheckboxComponent.htmlTagName, IgcToolActionCheckboxComponent);
            }
        }
        /**
         * Gets or sets if the tool action is checked.
        */
        get isChecked() {
            return this.i.hb;
        }
        set isChecked(v) {
            this.i.hb = ensureBool(v);
            this._a("isChecked", this.i.hb);
        }
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get uncheckedBackgroundColor() {
            return brushToString(this.i.h1);
        }
        set uncheckedBackgroundColor(v) {
            this.i.h1 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.h1));
        }
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get actualUncheckedBackgroundColor() {
            return brushToString(this.i.hx);
        }
        set actualUncheckedBackgroundColor(v) {
            this.i.hx = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.hx));
        }
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get checkedBackgroundColor() {
            return brushToString(this.i.hz);
        }
        set checkedBackgroundColor(v) {
            this.i.hz = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.hz));
        }
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get actualCheckedBackgroundColor() {
            return brushToString(this.i.hv);
        }
        set actualCheckedBackgroundColor(v) {
            this.i.hv = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.hv));
        }
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get uncheckedBorderColor() {
            return brushToString(this.i.h2);
        }
        set uncheckedBorderColor(v) {
            this.i.h2 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.h2));
        }
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get actualUncheckedBorderColor() {
            return brushToString(this.i.hy);
        }
        set actualUncheckedBorderColor(v) {
            this.i.hy = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.hy));
        }
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get checkedBorderColor() {
            return brushToString(this.i.h0);
        }
        set checkedBorderColor(v) {
            this.i.h0 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.h0));
        }
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get actualCheckedBorderColor() {
            return brushToString(this.i.hw);
        }
        set actualCheckedBorderColor(v) {
            this.i.hw = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.hw));
        }
    }
    IgcToolActionCheckboxComponent._observedAttributesIgcToolActionCheckboxComponent = null;
    IgcToolActionCheckboxComponent.htmlTagName = "igc-tool-action-checkbox";
    IgcToolActionCheckboxComponent._isElementRegistered = false;
    return IgcToolActionCheckboxComponent;
})();
